setLiveLocationTag method

  1. @Deprecated("Please get in touch with the MOVE SDK team if you want to use this method.")
  2. @override
Future<bool> setLiveLocationTag(
  1. String? tag
)
override

Implementation

@Deprecated(
  "Please get in touch with the MOVE SDK team if you want to use this method.",
)
@override
Future<bool> setLiveLocationTag(String? tag) async {
  var result = await methodChannel.invokeMethod(
    'setLiveLocationTag',
    <String, dynamic>{'tag': tag},
  );
  return result;
}