shutdown method

Future<MoveShutdownResult> shutdown({
  1. bool force = true,
  2. int? timeoutSeconds,
})

Shutdown SDK shared instance.

Stops SDK services, sends the queued user data, and de-intialized the SDK. After that is executed, the SDK State.uninitialized is triggered. The force parameter (default: true) will discard pending data to be uploaded. With force = true shudown will always succseed. The timeoutSeconds parameter (in seconds) bounds how long the SDK tries to send pending data before shutting down. Use with force = false.

Implementation

Future<MoveShutdownResult> shutdown(
    {bool force = true, int? timeoutSeconds}) {
  throw UnimplementedError('shutdown() has not been implemented.');
}