setLiveLocationTag method
- @Deprecated("Please get in touch with the MOVE SDK team if you want to use this method.")
- @override
- String? tag
override
Implementation
@Deprecated(
"Please get in touch with the MOVE SDK team if you want to use this method.",
)
@override
Future<bool> setLiveLocationTag(String? tag) async {
var result = await methodChannel.invokeMethod(
'setLiveLocationTag',
<String, dynamic>{'tag': tag},
);
return result;
}